<?php
/**
 * @package   Table 9 Element for YOOtheme Pro
 * @author    Flart Studio https://www.flart.studio
 * @copyright Copyright (C) Flart Studio
 * @license   GNU General Public License version 3, or later
 */

use YOOtheme\Arr;

$uniqid = strval('fs_table_' . substr(md5(uniqid(rand(), true)), -7));
$dtid = strval('fs-datatable-' . str_replace("#","-",$id));
$defCol = 0;

$props['table_datatables_filter'] ?	$dtFiltered = array() : $dtFiltered = '';
$props['table_datatables_filter_image'] = false;


$text_fields = ['title', 'text_1', 'text_2', 'text_3', 'text_4', 'text_5', 'text_6', 'text_7', 'text_8', 'text_9'];

switch ($props['table_order']) {
    case 1:
        $fields = ['title', 'text_1', 'text_2', 'text_3', 'image', 'text_4', 'text_5', 'text_6', 'text_7', 'text_8', 'text_9', 'link'];
        break;
    case 2:
        $fields = ['title', 'image', 'text_1', 'text_2', 'text_3', 'text_4', 'text_5', 'text_6', 'text_7', 'text_8', 'text_9', 'link'];
        break;
    case 3:
        $fields = ['image', 'title', 'link', 'text_2', 'text_1', 'text_2', 'text_3', 'text_4', 'text_5', 'text_6', 'text_7', 'text_8', 'text_9'];
        break;
    case 4:
        $fields = ['image', 'title', 'text_1', 'text_2', 'text_3', 'text_4', 'text_5', 'text_6', 'text_7', 'text_8', 'text_9', 'link'];
        break;
    case 5:
        $fields = ['title', 'text_1', 'text_2', 'text_3', 'text_4', 'text_5', 'text_6', 'text_7', 'text_8', 'text_9', 'link', 'image'];
        break;
    case 6:
        $fields = ['title', 'text_1', 'text_2', 'text_3', 'text_4', 'text_5', 'text_6', 'text_7', 'text_8', 'text_9', 'image', 'link'];
        break;
}

// Find empty fields
$filtered = array_values(Arr::filter($fields, function ($field) use ($props, $children) {
    return $props["show_{$field}"] && Arr::some($children, function ($child) use ($field) {
        return $child->props[$field];
    });
}));


//Datatable
if($props['table_datatables_paging']){
	$props['table_datatables_scrollY'] = '';
}
else if ($props['table_datatables_scroll'] && $props['table_datatables_scrollY']){
	$props['table_datatables_paging'] = false;
	$props['table_datatables_lengthChange'] = false;
	$props['table_datatables_info'] = false;	
}
else if(!$props['table_datatables_paging'] && !$props['table_datatables_scroll']) {
	$props['table_datatables_scrollY'] = '';
	$props['table_datatables_paging'] = false;
	$props['table_datatables_info'] = false;
}

$el = $this->el('div', [

    'class' => [
        'fs-table',
		'uk-overflow-auto {@table_responsive: overflow}',
		'uk-margin-large-bottom',
    ],

]);

$table_wrapper = $this->el('div', [

	'id' => [
        $uniqid => $props['enable_datatables'],
    ],

]);


$table = $this->el('table', [

	'id' => [
        $dtid => $props['enable_datatables'],
    ],
	
	'class' => [
		// Style
        'uk-table',
		'dataTable' => $props['enable_datatables'],
		'dataTable-info' => $props['table_datatables_info'],
		'dataTable-search' => $props['table_datatables_search'],
		'dataTable-ordering' => $props['table_datatables_ordering'],
		'dataTable-filter' => $props['table_datatables_filter'],
		'dataTable-pagination' => $props['table_datatables_paging'],
        'uk-table-{table_style}',
        'uk-table-hover {@table_hover}',
        'uk-table-justify {@table_justify}',

        // Size
        'uk-table-{table_size}',

        // Vertical align
        'uk-table-middle {@table_vertical_align}',

        // Responsive
        'uk-table-responsive {@table_responsive: responsive}',
    ],
	
	'style' => [
        'width:100%!important;',
    ],

]);

?>

<?= $el($props, $attrs) ?>	
	<?= $table_wrapper($props) ?>
		<?= $this->render("{$__dir}/template-title", compact('props')) ?>	
		<?= $table($props) ?>

			<?php if (Arr::some($filtered, function ($field) use ($props) { return $props["table_head_{$field}"]; })) : ?>
			<thead>
				<tr>
					
					<?php foreach ($filtered as $i => $field) {
						
						//hide link column
						if(!$props['link_text'] && $field === 'link') {continue;}
						
						is_array($dtFiltered) && $props['table_datatables_filter_' . $field] ? array_push($dtFiltered, $i) : false;
						
						//Datatables default sorting column
						if (!$defCol && $field != 'image') {
							$sd = $props['table_datatables_sorting_default'] ?: '';
							$se = $props['table_datatables_sorting_' . $field];
							$se && $sd === $field ? $defCol = $i : $defCol = 0;
						}
						
						$lastColumn = $i !== 0 && !isset($filtered[$i + 1]);

						echo $this->el('th', [
							
							'class' => [

								'fs-thead-column fs-thead-column-' . $i,
								
								//Visibility
								'{' .$field. '_visibility}'  => $props[$field. '_visibility'],
								'has-filter' => $props['table_datatables_filter_' . $field],
								
								//Text Align
								'uk-text-{title_align}'  => $props['title_align']  && $field === 'title',
								'uk-text-{text_1_align}' => $props['text_1_align'] && $field === 'text_1',
								'uk-text-{text_2_align}' => $props['text_2_align'] && $field === 'text_2',
								'uk-text-{text_3_align}' => $props['text_3_align'] && $field === 'text_3',
								'uk-text-{text_4_align}' => $props['text_4_align'] && $field === 'text_4',
								'uk-text-{text_5_align}' => $props['text_5_align'] && $field === 'text_5',
								'uk-text-{text_6_align}' => $props['text_6_align'] && $field === 'text_6',
								'uk-text-{text_7_align}' => $props['text_7_align'] && $field === 'text_7',
								'uk-text-{text_8_align}' => $props['text_8_align'] && $field === 'text_8',
								'uk-text-{text_9_align}' => $props['text_9_align'] && $field === 'text_9',
								
								//Datatables Sorting
								'th-image  no-sort' => $field === 'image',
								'th-' .$field. ' no-sort' => !$props['table_datatables_sorting_' . $field] && $field != 'image',
								
								// Last column alignment
								'uk-text-{table_last_align}[@m {@table_responsive: responsive}]' => $lastColumn,

								// Text align need to be set for table heading
								'uk-text-{text_align}[@{text_align_breakpoint} [uk-text-{text_align_fallback}] {@!text_align: justify}]' => !$lastColumn || !$props['table_last_align'] && !$props['title_align'] || !$props['text_1_align'] || !$props['text_2_align'] || !$props['text_3_align'] || !$props['text_4_align'] || !$props['text_5_align'] || !$props['text_6_align'] || !$props['text_7_align'] || !$props['text_8_align'] || !$props['text_9_align'],

								// Text nowrap
								'uk-text-nowrap' => $field == 'link' || in_array($field, $text_fields) && $props["table_width_{$field}"] == 'shrink',
							],

						], $props["table_head_{$field}"])->render($props);

					} ?>

				</tr>

			</thead>
			<?php endif ?>

			<tbody class="fs-load-more-container">
			<?php foreach ($children as $i => $child) : ?>
			<tr class="el-item fs-table-row fs-table-row-<?php echo $i ;?> fs-load-more-item"><?= $builder->render($child, ['i' => $i, 'element' => $props, 'fields' => $fields, 'text_fields' => $text_fields, 'filtered' => $filtered]) ?></tr>
			<?php endforeach ?>
			</tbody>
			
			<?php if ($props['table_datatables_filter'] && $props['table_datatables_filter_position'] == 'footer' && !empty($dtFiltered) && Arr::some($filtered, function ($field) use ($props) { return $props["table_head_{$field}"]; })) : ?>
			<tfoot>
				<tr>
					<?php foreach ($filtered as $i => $field) {
						//hide link column
						if(!$props['link_text'] && $field === 'link') {continue;}
						$lastColumn = $i !== 0 && !isset($filtered[$i + 1]);
						echo $this->el('th', [

							'class' => [                            
								
								'fs-tfoot-column fs-tfoot-column-' . $i,							
								
								'{title_visibility}'  => $props['title_visibility']  && $field === 'title',
								'{text_1_visibility}' => $props['text_1_visibility'] && $field === 'text_1',
								'{text_2_visibility}' => $props['text_2_visibility'] && $field === 'text_2',
								'{text_3_visibility}' => $props['text_3_visibility'] && $field === 'text_3',
								'{text_4_visibility}' => $props['text_4_visibility'] && $field === 'text_4',
								'{text_5_visibility}' => $props['text_5_visibility'] && $field === 'text_5',
								'{text_6_visibility}' => $props['text_6_visibility'] && $field === 'text_6',
								'{text_7_visibility}' => $props['text_7_visibility'] && $field === 'text_7',
								'{text_8_visibility}' => $props['text_8_visibility'] && $field === 'text_8',
								'{text_9_visibility}' => $props['text_9_visibility'] && $field === 'text_9',
								'{image_visibility}'  => $props['image_visibility']  && $field === 'image',
								'{link_visibility}'   => $props['link_visibility']   && $field === 'link'
							]
							
						])->render($props);

					} ?>

				</tr>
			</tfoot>
			<?php endif ?>

		<?= $table->end(); ?>	
	<?= $table_wrapper->end(); ?>
<?= $el->end(); ?>

<?php if($props['enable_datatables']) : ?>
	<?php include "{$__dir}/../assets/js/fs-table-dataTables.js.php"; ?>
<?php endif ?>